MapRoute class

路线规划

Constructors

MapRoute()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bicyclingRoute(String origin, String destination, String key) → Future<BicyclingRouteData>
获取骑行路线数据 origin: 起点坐标 destination: 终点坐标 key: 高德web服务api类型key 申请地址:https://lbs.amap.com/dev/